4.44. umbra.ui.languages — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.44. umbra.ui.languages

languages.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines languages manipulation related objects.

Others:

## 4.44.1. Module Attributes

`umbra.ui.languages.` `LOGGER`

`umbra.ui.languages.` `PYTHON_GRAMMAR_FILE`

`umbra.ui.languages.` `LOGGING_GRAMMAR_FILE`

`umbra.ui.languages.` `TEXT_GRAMMAR_FILE`

`umbra.ui.languages.` `LANGUAGES_ACCELERATORS`

`umbra.ui.languages.` `DEFAULT_INDENT_MARKER`

`umbra.ui.languages.` `PYTHON_LANGUAGE`

`umbra.ui.languages.` `LOGGING_LANGUAGE`

`umbra.ui.languages.` `TEXT_LANGUAGE`

## 4.44.2. Functions

`umbra.ui.languages.` `getObjectFromLanguageAccelerators`(accelerator)

  This definition returns the object associated to given accelerator.

  Parameters: | accelerator – Accelerator. ( String )
  Returns: | Object. ( Object )

`umbra.ui.languages.` `getLanguageDescription`(grammarfile)

  This definition gets the language description from given language grammar file.

  Parameters: | grammarfile – Language grammar. ( String )
  Returns: | Language description. ( Language )

`umbra.ui.languages.` `getPythonLanguage`()

  This definition returns the Python language description.

  Returns: | Python language description. ( Language )

`umbra.ui.languages.` `getLoggingLanguage`()

  This definition returns the Logging language description.

  Returns: | Logging language description. ( Language )

`umbra.ui.languages.` `getTextLanguage`()

  This definition returns the Text language description.

  Returns: | Text language description. ( Language )

## 4.44.3. Classes

class `umbra.ui.languages.` `Language`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  This class represents a storage object for the `Editor` class language description.

  Parameters: | **kwargs – name, file, parser, extensions, highlighter, completer, preInputAccelerators, postInputAccelerators, visualAccelerators, indentMarker, commentMarker, commentBlockMarkerStart, commentBlockMarkerEnd, symbolsPairs, indentationSymbols, rules, tokens, theme. ( Key / Value pairs )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »